FileStreamCallback typedef
FileStreamCallback =
Stream<Uint8List> Function(NativeDragFileItem<Object> item, String fileName, String url, ProgressController progressController)
Callback which is called when the native layer needs the file bytes
item is the corresponding NativeDragFileItem object
fileName is the fileName
url is the location where the user dropped the drag file item
progressController must be used to inform about the current progress
must return a Stream to write to
Implementation
typedef FileStreamCallback = Stream<Uint8List> Function(
NativeDragFileItem item, String fileName, String url, ProgressController progressController);